# PyApnea v0.0.3

Python package related to apnea data analysis.

This version contains functions to read session files from OSCAR software (https://www.sleepfiles.com/OSCAR/)

Documentation can be found on [ReadTheDocs](https://pyapnea.readthedocs.io/en/latest/)



